@@ -8,6 +8,7 @@
 #' @param gsname Name of the gene set (e.g., GO, KEGG, etc.)
 #' @param version version of the gene set
 #' @param accessed_date date to obtain the gene set data
+#' @param keytype keytype of genes
 #' @param info extra information
 #'
 #' @return A 'GSON' instance
@@ -24,7 +25,7 @@
 #' gson(gsid2gene=gsid2gene, gsid2name=gsid2name, species=species, version=version)
 gson <- function(gsid2gene, gsid2name = NULL, gene2name = NULL,
                  species = NULL, gsname = NULL, version = NULL,
-                 accessed_date = NULL, info = NULL) {
+                 accessed_date = NULL, keytype = NULL, info = NULL) {
 
     new("GSON",
         gsid2gene = gsid2gene,
@@ -34,6 +35,7 @@ gson <- function(gsid2gene, gsid2name = NULL, gene2name = NULL,
         gsname = gsname,
         version = version,
         accessed_date = accessed_date,
-        info = info)
+        info = info,
+        keytype = keytype)
 }
 
